<?php /* ページ用テンプレート */ ?>

<?php /* get_header() を使ってページ共通ヘッダーテンプレートを読み込みます。 */ ?>
<?php get_header(); ?>

<div class="main">
	<main class="container">
<?php /*
	have_posts() は現在の WordPress クエリにループできる結果があるかどうかをチェックします。
	WordPress クエリループを処理する一般形は、以下の通りです。

	if ( have_posts() ) {				// 処理するクエリがあるかのチェック
		while ( have_posts() ) {		// 処理するクエリが無くなるまでループ
			the_post();					// 処理するクエリ情報の設定
			・・・						// 個別クエリの処理
		}
	}

	個別クエリの処理で使用している関数は、以下の通りです。

	get_permalink()						// 投稿のパーマリンクを取得
	get_template_directory_uri()		// 投稿のディレクトリィ URI を取得
	get_the_author()					// 投稿の投稿者名を取得
	get_the_date()						// 投稿の日付を取得
	get_the_excerpt()					// 投稿の投稿概要を取得
	get_the_ID()						// 投稿の投稿 ID を取得
	get_the_post_thumbnail_url()		// 投稿のアイキャッチ画像 URL を取得
	get_the_title()						// 投稿のタイトルを取得
	has_post_thumbnail()				// 投稿にアイキャッチ画像が登録されているかのチェック
	is_single()							// 固定ページ以外の個別の投稿ページが表示中かのチェック
	is_singular()						// 個別の投稿ページ（一覧以外）が表示中かのチェック
	next_post_link()					// 日付順でひとつ次の投稿のリンクを表示
	previous_post_link()				// 日付順でひとつ前の投稿のリンクを表示
	the_content()						// 投稿の本文を表示
	the_title()							// 投稿のタイトルを表示
	the_posts_pagination()				// 投稿の前と次のページ番号セットを表示
	wp_link_pages()						// ページ分割された投稿ページリンクを表示

*/ ?>
<?php
if ( have_posts() ) {
	while ( have_posts() ) {
		the_post();
		if ( is_singular() ) {							// ページ（投稿、固定など）表示
			the_title( '<h1>', '</h1>' );				// タイトル
			the_content();								// ページコンテンツ
		}
		else {											// 投稿一覧表示
			$permalink = esc_url( get_permalink() );	// URL
			$title = get_the_title();					// タイトル
			if ( has_post_thumbnail() ) {				// アイキャッチ画像URL（サムネイルURL）
				// アイキャッチ画像のURL取得（引数1：サイズ：'thumbnail'、'medium'、'large'、'full'
				$thumbnail = 'src="' . get_the_post_thumbnail_url( get_the_ID(), 'thumbnail' ) . '" alt="アイキャッチ"';
			}
			else {
				// アイキャッチ画像が未登録時は、テーマフォルダの「images/noimage.pmg」を使用
				$thumbnail = 'src="' . get_template_directory_uri() . '/images/noimage.png' . '" alt="イメージなし"';
			}
			$excerpt = get_the_excerpt();				// 抜粋
			$date = get_the_date( 'Y-m-d' );			// 投稿日付
			$time = get_the_date( 'H:i:s' );			// 投稿時間
			$author = get_the_author();					// 投稿者
?>
			<article class="blog-list__list-item">
				<a href="<?php echo $permalink; ?>" class="blog-item">
					<div class="blog-item__content">
						<div class="blog-item__thumbnail">
							<img <?php echo $thumbnail; ?>>
						</div>
						<div class="blog-item__detail">
							<div class="blog-item__element">
								<h2 class="blog-item__title"><?php echo $title; ?></h2>
								<p class="blog-item__datetime"><?php echo $date . '<br>' . $time; ?></p>
								<p class="blog-item__author"><?php echo $author; ?></p>
							</div>
							<p class="blog-item__read"><?php echo $excerpt; ?></p>
						</div>
					</div>
				</a>
			</article>
<?php
		}
	}
	if ( is_singular() ) {								// ページ（投稿、固定など）表示
		wp_link_pages( array(							// 改ページ（複数ページ）処理
			'before'           => '<div class="blog-pages-pagination">',
			'after'            => '</div>' . PHP_EOL,	// before/afterは、前後に付加する文字
			'link_before'      => '',					// リンクテキストの前に負荷する文字
			'link_after'       => '',					// リンクテキストの後ろに負荷する文字
			'next_or_number'   => 'number',				// 'number'：ページ番号、'next'：前／次ページ
			'separator'        => ' ',					// ページ番号間の文字
			'nextpagelink'     => __( 'Next page' ),	// 次のページのリンクテキスト
			'previouspagelink' => __( 'Previous page' ),// 前のページのリンクテキスト
			'pagelink'         => 'ページ %',			// ページ番号のフォーマット（%はページ番号）
			'echo'             => true,					// true：表示、false：返却
		) );
		if ( is_single() ) {							// 投稿ページ
?>
			<div class="blog-single_pagination">
				<p><?php previous_post_link(); ?></p>
				<p><?php next_post_link(); ?></p>
			</div>
<?php
		}
	}
	else {												// 投稿一覧表示
		the_posts_pagination( array(					// ページネーションを表示
			'mid_size'  => 2,							// 現在のページの左右に表示するページ番号の数
			'prev_text' => __('Previous'),				// 前のセットへのリンクテキスト
			'next_text' => __('Next')					// 次のセットへのリンクテキスト
		) );
	}
}
?>
	</main>
</div>

<?php /* get_footer() を使ってページ共通フッターテンプレートを読み込みます。 */ ?>
<?php get_footer(); ?>
